@@ -6,7 +6,7 @@
 #' @inheritParams summarize_gene
 #' @examples
 #'
-#' # Using the built-in data set, P_sojae_survey
+#' # Using the built-in data set, `P_sojae_survey`
 #' data(P_sojae_survey)
 #'
 #' P_sojae_survey
@@ -50,9 +50,7 @@ calculate_complexities <- function(x,
     .gene = gene,
     .perc_susc = perc_susc
   )
-
-  # CRAN NOTE avoidance
-  distribution <- N_samp <- i.N <- NULL # nocov
+  
   # The susceptible control is removed from all samples in the data set so that
   #  it will not affect complexity calculations and a new data set is made that
   #  it does not contain susceptible controls.
@@ -119,18 +117,18 @@ calculate_complexities <- function(x,
 #'  distribution (number per complexity) calculated by
 #'  [calculate_complexities()].
 #' @param object a \CRANpkg{hagis} `complexities` object generated by
-#'  [calculate_complexities()]. Character.
+#'  [calculate_complexities()]. `Character`.
 #' @param type a vector of values for which the bar plot is desired. Specify
 #'  whether to return a graph of the frequency of complexities as a percentage,
-#'  "`percentage`", or as the count, "`count`". Character.
+#'  "`percentage`", or as the count, "`count`". `Character`.
 #' @param color a named or hexadecimal color value to use for the bar color
 #' @param order sort the x-axis of the bar chart by ascending or descending
 #' order of `frequency`. Accepts `ascending` or `descending` input values.
-#' Defaults to `complexity` value. Character.
+#' Defaults to `complexity` value. `Character`.
 #' @param ... passed to the chosen `geom(s)`
 #'
 #' @examples
-#' # Using the built-in data set, P_sojae_survey
+#' # Using the built-in data set, `P_sojae_survey`
 #' data(P_sojae_survey)
 #'
 #' # calculate susceptibilities with a 60 % cutoff value
@@ -158,9 +156,6 @@ autoplot.hagis.complexities <-
            order = NULL,
            ...) {
 
-    #CRAN Note avoidance
-    complexity <- frequency <- NULL
-
     # create a single data.frame to use in the ggplot call
     z <- object[[1]]
 
@@ -200,8 +195,6 @@ autoplot.hagis.complexities <-
     }
 
     plot_count <- function(.data, .color) {
-      #CRAN Note avoidance
-      complexity <- distribution <- NULL
       num_plot <- ggplot2::ggplot(data = .data,
                                   ggplot2::aes(x = stats::reorder(complexity,
                                                                   order),
@@ -233,16 +226,14 @@ autoplot.hagis.complexities <-
 #' Create summary table of binary reactions by sample
 #'
 #' Tally a summary by sample or isolate. This code takes the "Susceptible.1"
-#'  column and summarises it by gene for your total Isolates pathogenic on each
-#'  sample.
+#'  column and summarises it by gene for your total "Isolates" pathogenic on
+#'  each sample.
 #'
 #' @param x A \CRANpkg{hagis} `complexities` object generated by
-#'  [calculate_complexities()]. Character.
-#' @return A `data.table` that tallies the results by sample
+#'  [calculate_complexities()]. `Character`.
+#' @return A `data.table` that tallies the results by sample.
 #' @noRd
-#' @export
 .create_summary_isolate <- function(.y) {
-  susceptible.1 <- NULL
   .y <- .y[, list(N_samp = sum(susceptible.1)), by = list(sample)]
   return(.y)
 }
@@ -277,7 +268,6 @@ summary.hagis.complexities <- function(object, ...) {
 #' @param ... ignored
 #' @export
 #' @noRd
-
 print.summary.complexities <- function(x,
                                        digits = max(3L,
                                                     getOption("digits") - 3L),
@@ -294,7 +284,7 @@ print.summary.complexities <- function(x,
 #' Pander Method for hagis summary complexities
 #'
 #' Prints a \CRANpkg{hagis} complexities summary in Pandoc's markdown.
-#' @param x a complexities object
+#' @param x a `complexities` object
 #' @param caption caption (string) to be shown under the table
 #' @param ... optional parameters passed to raw `pandoc.table` function
 #' @importFrom pander pander
